local LrDialogs = import "LrDialogs"
local LrFileUtils = import "LrFileUtils"
local LrLogger = import "LrLogger"
local LrPathUtils = import "LrPathUtils"
local LrTasks = import "LrTasks"

local myLogger = LrLogger( "libraryLogger" )
myLogger:enable( "print" )

local CopyToClipboard = {
	hideSections = { "exportLocation", "fileNaming", "metadata", "video" },

	allowFileFormats = { "TIFF", "JPEG", "PNG" },

	allowColorSpaces = nil,

	exportPresetFields = {}
}

function CopyToClipboard.processRenderedPhotos( functionContext, exportContext )
	local exportSession = exportContext.exportSession

	local format = exportContext.propertyTable["< contents >"].LR_format;


	for _, rendition in exportContext:renditions{ stopIfCanceled = true } do
		local success, pathOrMessage = rendition:waitForRender()

		--myLogger:trace( pathOrMessage )

		if success then
			local command
			local quotedCommand
			if WIN_ENV == true then
				local psCommand =
					"[Reflection.Assembly]::LoadWithPartialName('System.Drawing');" ..
					"[Reflection.Assembly]::LoadWithPartialName('System.Windows.Forms');" ..
					"$f=get-item('" .. pathOrMessage .. "');" ..
					"$i=[System.Drawing.Image]::Fromfile($f);" ..
					"[System.Windows.Forms.Clipboard]::SetImage($i);" ..
					"$i.Dispose();"

				command = "powershell " .. psCommand
				quotedCommand = '"' .. command .. '"'
			else
				command = "/usr/bin/osascript -e 'set the clipboard to (read (POSIX file \"" .. pathOrMessage .. "\") as " .. format .. " picture)'"
				quotedCommand = command
			end

			--myLogger:trace( quotedCommand )

			local executionResult = LrTasks.execute( quotedCommand )

			if executionResult ~= 0 then
				LrDialogs.message( "The photo couldn't be copied to the clipboard. Sorry 😔" )
				break
			end

			LrDialogs.showBezel( "Copy to clipboard successful.", 3 )

			LrFileUtils.delete( pathOrMessage )
		end

		break
	end
end

return CopyToClipboard
